@@ -4,10 +4,13 @@ from yandex_checkout.domain.response.receipt_response import ReceiptResponse
 
 
 class ReceiptListResponse(ResponseObject):
+
     __type = None
 
     __items = None
 
+    __next_cursor = None
+
     @property
     def type(self):
         return self.__type
@@ -16,6 +19,14 @@ class ReceiptListResponse(ResponseObject):
     def type(self, value):
         self.__type = value
 
+    @property
+    def next_cursor(self):
+        return self.__next_cursor
+
+    @next_cursor.setter
+    def next_cursor(self, value):
+        self.__next_cursor = value
+
     @property
     def items(self):
         return self.__items
